@@ -301,7 +301,7 @@ sub findslice {
          # $post = '';
          # $call = 'slice_if_pdl';     # handle runtime checks for $self type
          # $arg =~ s/\)$/,q{$found})/;  # add original argument string
-                                        # in case $self is not a piddle
+                                        # in case $self is not an ndarray
                                         # and the original call must be
                                         # generated
       }
@@ -456,7 +456,7 @@ PDL::NiceSlice - toward a nicer slicing syntax for PDL
   print $y((0),1:$end);     # use variables in the slice expression
   $x->xchg(0,1)->(($pos-1)) .= 0; # default method syntax
 
-  $idx = long 1, 7, 3, 0;   # a piddle of indices
+  $idx = long 1, 7, 3, 0;   # an ndarray of indices
   $x(-3:2:2,$idx) += 3;     # mix explicit indexing and ranges
   $x->clump(1,2)->(0:30);   # 'default method' syntax
   $x(myfunc(0,$var),1:4)++; # when using functions in slice expressions
@@ -608,13 +608,13 @@ necessarily obvious for the casual user).
 
 =head1 The new slicing syntax
 
-Using C<PDL::NiceSlice> slicing piddles becomes so much easier since, first of
+Using C<PDL::NiceSlice> slicing ndarrays becomes so much easier since, first of
 all, you don't need to make explicit method calls. No
 
   $pdl->slice(....);
 
 calls, etc. Instead, C<PDL::NiceSlice> introduces two ways in which to
-slice piddles without too much typing:
+slice ndarrays without too much typing:
 
 =over 2
 
@@ -628,9 +628,9 @@ for example
 =item *
 
 using the so called I<default method> invocation in which the
-piddle object is treated as if it were a reference to a
+ndarray object is treated as if it were a reference to a
 subroutine (see also L<perlref>). Take this example that slices
-a piddle that is part of a perl list C<@b>:
+an ndarray that is part of a perl list C<@b>:
 
   $c = $b[0]->(0:-3:4,(0));
 
@@ -645,7 +645,7 @@ An arglist in parentheses following directly after a scalar variable
 name that is I<not> preceded by C<&> will be resolved as a slicing
 command, e.g.
 
-  $x(1:4) .= 2;         # only use this syntax on piddles
+  $x(1:4) .= 2;         # only use this syntax on ndarrays
   $sum += $x(,(1));
 
 However, if the variable name is immediately preceded by a C<&>,
@@ -706,14 +706,14 @@ name. Instead, use the I<default method> syntax in such cases:
 
   $x->xchg(0,1)->(0);
 
-Similarly, if you have a list of piddles C<@pdls>:
+Similarly, if you have a list of ndarrays C<@pdls>:
 
   $y = $pdls[5]->(0:-1);
 
 =head2 The argument list
 
 The argument list is a comma separated list. Each argument specifies
-how the corresponding dimension in the piddle is sliced. In contrast
+how the corresponding dimension in the ndarray is sliced. In contrast
 to usage of the L<PDL::Slices/slice> method the arguments should
 I<not> be quoted. Rather freely mix literals (1,3,etc), perl
 variables and function invocations, e.g.
@@ -776,7 +776,7 @@ Four modifiers are currently implemented:
 
 =item *
 
-C<_> : I<flatten> the piddle before applying the slice expression. Here
+C<_> : I<flatten> the ndarray before applying the slice expression. Here
 is an example
 
    $y = sequence 3, 3;
@@ -794,7 +794,7 @@ which is quite different from the same slice expression without the modifier
 
 =item *
 
-C<|> : L<sever|PDL::Core/sever> the link to the piddle, e.g.
+C<|> : L<sever|PDL::Core/sever> the link to the ndarray, e.g.
 
    $x = sequence 10;
    $y = $x(0:2;|)++;  # same as $x(0:2)->sever++
@@ -874,7 +874,7 @@ whenever possible.
 =head2 Argument formats
 
 In slice expressions you can use ranges and secondly,
-piddles as 1D index lists (although compare the description
+ndarrays as 1D index lists (although compare the description
 of the C<?>-modifier above for an exception).
 
 =over 2
@@ -896,7 +896,7 @@ Examples:
 
 Just as with L<PDL::Slices/slice> negative indices count from the end of the dimension
 backwards with C<-1> being the last element. If the start index is larger
-than the stop index the resulting piddle will have the elements in reverse
+than the stop index the resulting ndarray will have the elements in reverse
 order between these limits:
 
   print $x(-2:0:2);
@@ -908,7 +908,7 @@ A single index just selects the given index in the slice
  [5]
 
 Note, however, that the corresponding dimension is not removed from
-the resulting piddle but rather reduced to size 1:
+the resulting ndarray but rather reduced to size 1:
 
   print $x(5)->info
  PDL: Double D [1]
@@ -919,7 +919,7 @@ in parentheses (again similar to the L<PDL::Slices/slice> syntax):
   print $x((5));
  5
 
-In this particular example a 0D piddle results. Note that this syntax is
+In this particular example a 0D ndarray results. Note that this syntax is
 only allowed with a single index. All these will be errors:
 
   print $x((0,4));  # will work but not in the intended way
@@ -939,7 +939,7 @@ Alternative ways to select a whole dimension are
   print $x(0:,(0));
 
 Arguments for trailing dimensions can be omitted. In that case
-these dimensions will be fully kept in the sliced piddle:
+these dimensions will be fully kept in the sliced ndarray:
 
   $x = random 3,4,5;
   print $x->info;
@@ -957,9 +957,9 @@ As in L<PDL::Slices/slice>, you can insert a dummy dimension by preceding a
 single index argument with '*'.  A lone '*' inserts a dummy dimension of 
 order 1; a '*' followed by a number inserts a dummy dimension of that order.
 
-=item * piddle index lists
+=item * ndarray index lists
 
-The second way to select indices from a dimension is via 1D piddles
+The second way to select indices from a dimension is via 1D ndarrays
 of indices. A simple example:
 
   $x = random 10;
@@ -968,32 +968,32 @@ of indices. A simple example:
 
 This way of selecting indices was previously only possible using
 L<PDL::Slices/dice> (C<PDL::NiceSlice> attempts to unify the
-C<slice> and C<dice> interfaces). Note that the indexing piddles must
-be 1D or 0D. Higher dimensional piddles as indices will raise an error:
+C<slice> and C<dice> interfaces). Note that the indexing ndarrays must
+be 1D or 0D. Higher dimensional ndarrays as indices will raise an error:
 
   $x = sequence 5, 5;
   $idx2 = ones 2,2;
   $sum = $x($idx2)->sum;
- piddle must be <= 1D at /home/XXXX/.perldlrc line 93
+ ndarray must be <= 1D at /home/XXXX/.perldlrc line 93
 
-Note that using index piddles is not as efficient as using ranges.
+Note that using index ndarrays is not as efficient as using ranges.
 If you can represent the indices you want to select using a range
-use that rather than an equivalent index piddle. In particular,
-memory requirements are increased with index piddles (and execution
-time I<may> be longer). That said, if an index piddle is the way to
+use that rather than an equivalent index ndarray. In particular,
+memory requirements are increased with index ndarrays (and execution
+time I<may> be longer). That said, if an index ndarray is the way to
 go use it!
 
 =back
 
-As you might have expected ranges and index piddles can be freely
+As you might have expected ranges and index ndarrays can be freely
 mixed in slicing expressions:
 
   $x = random 5, 5;
   $y = $x(-1:2,pdl(3,0,1));
 
-=head2 piddles as indices in ranges
+=head2 ndarrays as indices in ranges
 
-You can use piddles to specify indices in ranges. No need to
+You can use ndarrays to specify indices in ranges. No need to
 turn them into proper perl scalars with the new slicing syntax.
 However, make sure they contain not more than one element! Otherwise
 a runtime error will be triggered. First a couple of examples that
@@ -1014,12 +1014,12 @@ illustrate proper usage:
 The next one raises an error 
 
   print $x($rg+1,:$rg(0:1));
- multielement piddle where only one allowed at XXX/Core.pm line 1170.
+ multielement ndarray where only one allowed at XXX/Core.pm line 1170.
 
-The problem is caused by using the 2-element piddle C<$rg(0:1)> as the
+The problem is caused by using the 2-element ndarray C<$rg(0:1)> as the
 stop index in the second argument C<:$rg(0:1)> that is interpreted as
-a range by C<PDL::NiceSlice>. You I<can> use multielement piddles as
-index piddles as described above but not in ranges. And
+a range by C<PDL::NiceSlice>. You I<can> use multielement ndarrays as
+index ndarrays as described above but not in ranges. And
 C<PDL::NiceSlice> treats any expression with unprotected C<:>'s as a
 range.  I<Unprotected> means as usual 
 I<"not occurring between matched parentheses">.
@@ -1056,7 +1056,7 @@ when working with L<Inline::Pdlpp>, see below.
 There is currently an undesired interaction between C<PDL::NiceSlice>
 and the new L<Inline::Pdlpp> module (currently only in 
 PDL CVS). Since PP code generally
-contains expressions of the type C<$var()> (to access piddles, etc)
+contains expressions of the type C<$var()> (to access ndarrays, etc)
 C<PDL::NiceSlice> recognizes those I<incorrectly> as
 slice expressions and does its substitutions. This is not a problem
 if you use the C<DATA> section for your Pdlpp code -- the recommended
